# coding: utf-8

# flake8: noqa
"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from equinix.services.fabricv4.models.access_point import AccessPoint
from equinix.services.fabricv4.models.access_point_selector import AccessPointSelector
from equinix.services.fabricv4.models.access_point_selector_type import AccessPointSelectorType
from equinix.services.fabricv4.models.access_point_type import AccessPointType
from equinix.services.fabricv4.models.actions import Actions
from equinix.services.fabricv4.models.add_operation import AddOperation
from equinix.services.fabricv4.models.all_physical_ports_response import AllPhysicalPortsResponse
from equinix.services.fabricv4.models.all_ports_response import AllPortsResponse
from equinix.services.fabricv4.models.api_config import ApiConfig
from equinix.services.fabricv4.models.api_services import ApiServices
from equinix.services.fabricv4.models.asset import Asset
from equinix.services.fabricv4.models.authentication_key import AuthenticationKey
from equinix.services.fabricv4.models.bgp_action_data import BGPActionData
from equinix.services.fabricv4.models.bgp_action_request import BGPActionRequest
from equinix.services.fabricv4.models.bgp_action_states import BGPActionStates
from equinix.services.fabricv4.models.bgp_actions import BGPActions
from equinix.services.fabricv4.models.bgp_actions_bulk_data import BGPActionsBulkData
from equinix.services.fabricv4.models.bgp_connection_ipv4 import BGPConnectionIpv4
from equinix.services.fabricv4.models.bgp_connection_ipv6 import BGPConnectionIpv6
from equinix.services.fabricv4.models.bgp_connection_operation import BGPConnectionOperation
from equinix.services.fabricv4.models.bgp_connection_operation_operational_status import BGPConnectionOperationOperationalStatus
from equinix.services.fabricv4.models.bandwidth_utilization import BandwidthUtilization
from equinix.services.fabricv4.models.bandwidth_utilization_unit import BandwidthUtilizationUnit
from equinix.services.fabricv4.models.bulk_physical_port import BulkPhysicalPort
from equinix.services.fabricv4.models.bulk_port import BulkPort
from equinix.services.fabricv4.models.bulk_port_request import BulkPortRequest
from equinix.services.fabricv4.models.change import Change
from equinix.services.fabricv4.models.change_status import ChangeStatus
from equinix.services.fabricv4.models.change_type import ChangeType
from equinix.services.fabricv4.models.changelog import Changelog
from equinix.services.fabricv4.models.cloud_router import CloudRouter
from equinix.services.fabricv4.models.cloud_router_access_point_state import CloudRouterAccessPointState
from equinix.services.fabricv4.models.cloud_router_action_request import CloudRouterActionRequest
from equinix.services.fabricv4.models.cloud_router_action_response import CloudRouterActionResponse
from equinix.services.fabricv4.models.cloud_router_action_state import CloudRouterActionState
from equinix.services.fabricv4.models.cloud_router_action_type import CloudRouterActionType
from equinix.services.fabricv4.models.cloud_router_actions_search_expression import CloudRouterActionsSearchExpression
from equinix.services.fabricv4.models.cloud_router_actions_search_filter import CloudRouterActionsSearchFilter
from equinix.services.fabricv4.models.cloud_router_actions_search_filters import CloudRouterActionsSearchFilters
from equinix.services.fabricv4.models.cloud_router_actions_search_or_filter import CloudRouterActionsSearchOrFilter
from equinix.services.fabricv4.models.cloud_router_actions_search_request import CloudRouterActionsSearchRequest
from equinix.services.fabricv4.models.cloud_router_actions_search_response import CloudRouterActionsSearchResponse
from equinix.services.fabricv4.models.cloud_router_actions_search_sort_by import CloudRouterActionsSearchSortBy
from equinix.services.fabricv4.models.cloud_router_actions_search_sort_criteria import CloudRouterActionsSearchSortCriteria
from equinix.services.fabricv4.models.cloud_router_actions_search_sort_direction import CloudRouterActionsSearchSortDirection
from equinix.services.fabricv4.models.cloud_router_change import CloudRouterChange
from equinix.services.fabricv4.models.cloud_router_change_operation import CloudRouterChangeOperation
from equinix.services.fabricv4.models.cloud_router_change_status import CloudRouterChangeStatus
from equinix.services.fabricv4.models.cloud_router_change_type import CloudRouterChangeType
from equinix.services.fabricv4.models.cloud_router_filter import CloudRouterFilter
from equinix.services.fabricv4.models.cloud_router_filters import CloudRouterFilters
from equinix.services.fabricv4.models.cloud_router_or_filter import CloudRouterOrFilter
from equinix.services.fabricv4.models.cloud_router_package import CloudRouterPackage
from equinix.services.fabricv4.models.cloud_router_package_type import CloudRouterPackageType
from equinix.services.fabricv4.models.cloud_router_post_request import CloudRouterPostRequest
from equinix.services.fabricv4.models.cloud_router_post_request_package import CloudRouterPostRequestPackage
from equinix.services.fabricv4.models.cloud_router_post_request_package_code import CloudRouterPostRequestPackageCode
from equinix.services.fabricv4.models.cloud_router_post_request_package_type import CloudRouterPostRequestPackageType
from equinix.services.fabricv4.models.cloud_router_post_request_type import CloudRouterPostRequestType
from equinix.services.fabricv4.models.cloud_router_search_request import CloudRouterSearchRequest
from equinix.services.fabricv4.models.cloud_router_simple_expression import CloudRouterSimpleExpression
from equinix.services.fabricv4.models.cloud_router_sort_by import CloudRouterSortBy
from equinix.services.fabricv4.models.cloud_router_sort_criteria import CloudRouterSortCriteria
from equinix.services.fabricv4.models.cloud_router_sort_direction import CloudRouterSortDirection
from equinix.services.fabricv4.models.code import Code
from equinix.services.fabricv4.models.connected_metro import ConnectedMetro
from equinix.services.fabricv4.models.connection import Connection
from equinix.services.fabricv4.models.connection_acceptance_data import ConnectionAcceptanceData
from equinix.services.fabricv4.models.connection_action import ConnectionAction
from equinix.services.fabricv4.models.connection_action_request import ConnectionActionRequest
from equinix.services.fabricv4.models.connection_change_operation import ConnectionChangeOperation
from equinix.services.fabricv4.models.connection_company_profile import ConnectionCompanyProfile
from equinix.services.fabricv4.models.connection_direction import ConnectionDirection
from equinix.services.fabricv4.models.connection_invitation import ConnectionInvitation
from equinix.services.fabricv4.models.connection_link import ConnectionLink
from equinix.services.fabricv4.models.connection_link_type import ConnectionLinkType
from equinix.services.fabricv4.models.connection_operation import ConnectionOperation
from equinix.services.fabricv4.models.connection_operation_operational_status import ConnectionOperationOperationalStatus
from equinix.services.fabricv4.models.connection_post_request import ConnectionPostRequest
from equinix.services.fabricv4.models.connection_priority import ConnectionPriority
from equinix.services.fabricv4.models.connection_redundancy import ConnectionRedundancy
from equinix.services.fabricv4.models.connection_response import ConnectionResponse
from equinix.services.fabricv4.models.connection_route_aggregation_data import ConnectionRouteAggregationData
from equinix.services.fabricv4.models.connection_route_aggregation_data_attachment_status import ConnectionRouteAggregationDataAttachmentStatus
from equinix.services.fabricv4.models.connection_route_aggregation_data_type import ConnectionRouteAggregationDataType
from equinix.services.fabricv4.models.connection_route_entry_filter import ConnectionRouteEntryFilter
from equinix.services.fabricv4.models.connection_route_entry_filters import ConnectionRouteEntryFilters
from equinix.services.fabricv4.models.connection_route_entry_or_filter import ConnectionRouteEntryOrFilter
from equinix.services.fabricv4.models.connection_route_entry_simple_expression import ConnectionRouteEntrySimpleExpression
from equinix.services.fabricv4.models.connection_route_entry_sort_by import ConnectionRouteEntrySortBy
from equinix.services.fabricv4.models.connection_route_entry_sort_direction import ConnectionRouteEntrySortDirection
from equinix.services.fabricv4.models.connection_route_filter_data import ConnectionRouteFilterData
from equinix.services.fabricv4.models.connection_route_filter_data_direction import ConnectionRouteFilterDataDirection
from equinix.services.fabricv4.models.connection_route_filter_data_type import ConnectionRouteFilterDataType
from equinix.services.fabricv4.models.connection_route_filters_base import ConnectionRouteFiltersBase
from equinix.services.fabricv4.models.connection_route_filters_base_direction import ConnectionRouteFiltersBaseDirection
from equinix.services.fabricv4.models.connection_route_search_request import ConnectionRouteSearchRequest
from equinix.services.fabricv4.models.connection_route_sort_criteria import ConnectionRouteSortCriteria
from equinix.services.fabricv4.models.connection_route_table_entry import ConnectionRouteTableEntry
from equinix.services.fabricv4.models.connection_route_table_entry_connection import ConnectionRouteTableEntryConnection
from equinix.services.fabricv4.models.connection_route_table_entry_search_response import ConnectionRouteTableEntrySearchResponse
from equinix.services.fabricv4.models.connection_route_table_entry_state import ConnectionRouteTableEntryState
from equinix.services.fabricv4.models.connection_routing_protocol_post_request import ConnectionRoutingProtocolPostRequest
from equinix.services.fabricv4.models.connection_search_response import ConnectionSearchResponse
from equinix.services.fabricv4.models.connection_side import ConnectionSide
from equinix.services.fabricv4.models.connection_side_additional_info import ConnectionSideAdditionalInfo
from equinix.services.fabricv4.models.connection_state import ConnectionState
from equinix.services.fabricv4.models.connection_type import ConnectionType
from equinix.services.fabricv4.models.connectivity_source import ConnectivitySource
from equinix.services.fabricv4.models.connectivity_source_type import ConnectivitySourceType
from equinix.services.fabricv4.models.custom_field import CustomField
from equinix.services.fabricv4.models.custom_field_data_type import CustomFieldDataType
from equinix.services.fabricv4.models.direct_connection_ipv4 import DirectConnectionIpv4
from equinix.services.fabricv4.models.direct_connection_ipv6 import DirectConnectionIpv6
from equinix.services.fabricv4.models.direction import Direction
from equinix.services.fabricv4.models.duration import Duration
from equinix.services.fabricv4.models.end_customer import EndCustomer
from equinix.services.fabricv4.models.equinix_status import EquinixStatus
from equinix.services.fabricv4.models.error import Error
from equinix.services.fabricv4.models.expression import Expression
from equinix.services.fabricv4.models.expression_operator import ExpressionOperator
from equinix.services.fabricv4.models.fabric_cloud_router_code import FabricCloudRouterCode
from equinix.services.fabricv4.models.fabric_cloud_router_packages import FabricCloudRouterPackages
from equinix.services.fabricv4.models.fabric_cloud_router_price import FabricCloudRouterPrice
from equinix.services.fabricv4.models.filter_body import FilterBody
from equinix.services.fabricv4.models.geo_coordinates import GeoCoordinates
from equinix.services.fabricv4.models.geo_scope_type import GeoScopeType
from equinix.services.fabricv4.models.get_all_connection_route_aggregations_response import GetAllConnectionRouteAggregationsResponse
from equinix.services.fabricv4.models.get_all_connection_route_filters_response import GetAllConnectionRouteFiltersResponse
from equinix.services.fabricv4.models.get_all_stream_asset_response import GetAllStreamAssetResponse
from equinix.services.fabricv4.models.get_all_stream_response import GetAllStreamResponse
from equinix.services.fabricv4.models.get_all_stream_subscription_response import GetAllStreamSubscriptionResponse
from equinix.services.fabricv4.models.get_response import GetResponse
from equinix.services.fabricv4.models.get_route_aggregation_get_connections_response import GetRouteAggregationGetConnectionsResponse
from equinix.services.fabricv4.models.get_route_aggregation_rules_response import GetRouteAggregationRulesResponse
from equinix.services.fabricv4.models.get_route_filter_get_connections_response import GetRouteFilterGetConnectionsResponse
from equinix.services.fabricv4.models.get_route_filter_rules_response import GetRouteFilterRulesResponse
from equinix.services.fabricv4.models.get_service_profiles_view_point_parameter import GetServiceProfilesViewPointParameter
from equinix.services.fabricv4.models.get_subscriptions_in_stream_response import GetSubscriptionsInStreamResponse
from equinix.services.fabricv4.models.get_time_services_package_by_code_package_code_parameter import GetTimeServicesPackageByCodePackageCodeParameter
from equinix.services.fabricv4.models.health_response import HealthResponse
from equinix.services.fabricv4.models.interface import Interface
from equinix.services.fabricv4.models.interface_type import InterfaceType
from equinix.services.fabricv4.models.internet_access import InternetAccess
from equinix.services.fabricv4.models.ip_block_price import IpBlockPrice
from equinix.services.fabricv4.models.ip_block_type import IpBlockType
from equinix.services.fabricv4.models.ipv4 import Ipv4
from equinix.services.fabricv4.models.json_patch_operation import JsonPatchOperation
from equinix.services.fabricv4.models.link import Link
from equinix.services.fabricv4.models.link_aggregation_group import LinkAggregationGroup
from equinix.services.fabricv4.models.link_protocol_connection import LinkProtocolConnection
from equinix.services.fabricv4.models.link_protocol_get_response import LinkProtocolGetResponse
from equinix.services.fabricv4.models.link_protocol_request_type import LinkProtocolRequestType
from equinix.services.fabricv4.models.link_protocol_response import LinkProtocolResponse
from equinix.services.fabricv4.models.link_protocol_service_token import LinkProtocolServiceToken
from equinix.services.fabricv4.models.link_protocol_state import LinkProtocolState
from equinix.services.fabricv4.models.link_protocol_type import LinkProtocolType
from equinix.services.fabricv4.models.marketing_info import MarketingInfo
from equinix.services.fabricv4.models.marketplace_subscription import MarketplaceSubscription
from equinix.services.fabricv4.models.marketplace_subscription_type import MarketplaceSubscriptionType
from equinix.services.fabricv4.models.md5 import Md5
from equinix.services.fabricv4.models.md5_type import Md5Type
from equinix.services.fabricv4.models.metal_interconnection import MetalInterconnection
from equinix.services.fabricv4.models.metric_interval import MetricInterval
from equinix.services.fabricv4.models.metrics import Metrics
from equinix.services.fabricv4.models.metro import Metro
from equinix.services.fabricv4.models.metro_error import MetroError
from equinix.services.fabricv4.models.metro_error_error_code import MetroErrorErrorCode
from equinix.services.fabricv4.models.metro_error_error_message import MetroErrorErrorMessage
from equinix.services.fabricv4.models.metro_response import MetroResponse
from equinix.services.fabricv4.models.network import Network
from equinix.services.fabricv4.models.network_change import NetworkChange
from equinix.services.fabricv4.models.network_change_operation import NetworkChangeOperation
from equinix.services.fabricv4.models.network_change_response import NetworkChangeResponse
from equinix.services.fabricv4.models.network_change_status import NetworkChangeStatus
from equinix.services.fabricv4.models.network_change_type import NetworkChangeType
from equinix.services.fabricv4.models.network_connections import NetworkConnections
from equinix.services.fabricv4.models.network_equinix_status import NetworkEquinixStatus
from equinix.services.fabricv4.models.network_filter import NetworkFilter
from equinix.services.fabricv4.models.network_filter_operator import NetworkFilterOperator
from equinix.services.fabricv4.models.network_operation import NetworkOperation
from equinix.services.fabricv4.models.network_post_request import NetworkPostRequest
from equinix.services.fabricv4.models.network_scope import NetworkScope
from equinix.services.fabricv4.models.network_search_field_name import NetworkSearchFieldName
from equinix.services.fabricv4.models.network_search_request import NetworkSearchRequest
from equinix.services.fabricv4.models.network_search_response import NetworkSearchResponse
from equinix.services.fabricv4.models.network_sort_by import NetworkSortBy
from equinix.services.fabricv4.models.network_sort_by_response import NetworkSortByResponse
from equinix.services.fabricv4.models.network_sort_criteria import NetworkSortCriteria
from equinix.services.fabricv4.models.network_sort_criteria_response import NetworkSortCriteriaResponse
from equinix.services.fabricv4.models.network_sort_direction import NetworkSortDirection
from equinix.services.fabricv4.models.network_sort_direction_response import NetworkSortDirectionResponse
from equinix.services.fabricv4.models.network_state import NetworkState
from equinix.services.fabricv4.models.network_type import NetworkType
from equinix.services.fabricv4.models.op_enum import OpEnum
from equinix.services.fabricv4.models.operation import Operation
from equinix.services.fabricv4.models.order import Order
from equinix.services.fabricv4.models.package import Package
from equinix.services.fabricv4.models.package_change_log import PackageChangeLog
from equinix.services.fabricv4.models.package_code import PackageCode
from equinix.services.fabricv4.models.package_response import PackageResponse
from equinix.services.fabricv4.models.package_type import PackageType
from equinix.services.fabricv4.models.pagination import Pagination
from equinix.services.fabricv4.models.pagination_request import PaginationRequest
from equinix.services.fabricv4.models.peering_type import PeeringType
from equinix.services.fabricv4.models.physical_port import PhysicalPort
from equinix.services.fabricv4.models.physical_port_settings import PhysicalPortSettings
from equinix.services.fabricv4.models.physical_port_type import PhysicalPortType
from equinix.services.fabricv4.models.port import Port
from equinix.services.fabricv4.models.port_additional_info import PortAdditionalInfo
from equinix.services.fabricv4.models.port_bmmr_type import PortBmmrType
from equinix.services.fabricv4.models.port_connectivity_source_type import PortConnectivitySourceType
from equinix.services.fabricv4.models.port_demarcation_point import PortDemarcationPoint
from equinix.services.fabricv4.models.port_device import PortDevice
from equinix.services.fabricv4.models.port_device_redundancy import PortDeviceRedundancy
from equinix.services.fabricv4.models.port_device_redundancy_priority import PortDeviceRedundancyPriority
from equinix.services.fabricv4.models.port_encapsulation import PortEncapsulation
from equinix.services.fabricv4.models.port_encapsulation_type import PortEncapsulationType
from equinix.services.fabricv4.models.port_expression import PortExpression
from equinix.services.fabricv4.models.port_interface import PortInterface
from equinix.services.fabricv4.models.port_lag import PortLag
from equinix.services.fabricv4.models.port_loa import PortLoa
from equinix.services.fabricv4.models.port_loa_type import PortLoaType
from equinix.services.fabricv4.models.port_notification import PortNotification
from equinix.services.fabricv4.models.port_notification_type import PortNotificationType
from equinix.services.fabricv4.models.port_operation import PortOperation
from equinix.services.fabricv4.models.port_operation_operational_status import PortOperationOperationalStatus
from equinix.services.fabricv4.models.port_order import PortOrder
from equinix.services.fabricv4.models.port_order_purchase_order import PortOrderPurchaseOrder
from equinix.services.fabricv4.models.port_order_purchase_order_selection_type import PortOrderPurchaseOrderSelectionType
from equinix.services.fabricv4.models.port_order_purchase_order_type import PortOrderPurchaseOrderType
from equinix.services.fabricv4.models.port_order_signature import PortOrderSignature
from equinix.services.fabricv4.models.port_order_signature_delegate import PortOrderSignatureDelegate
from equinix.services.fabricv4.models.port_order_signature_signatory import PortOrderSignatureSignatory
from equinix.services.fabricv4.models.port_physical_ports_type import PortPhysicalPortsType
from equinix.services.fabricv4.models.port_priority import PortPriority
from equinix.services.fabricv4.models.port_redundancy import PortRedundancy
from equinix.services.fabricv4.models.port_request import PortRequest
from equinix.services.fabricv4.models.port_search_field_name import PortSearchFieldName
from equinix.services.fabricv4.models.port_service_type import PortServiceType
from equinix.services.fabricv4.models.port_settings import PortSettings
from equinix.services.fabricv4.models.port_settings_package_type import PortSettingsPackageType
from equinix.services.fabricv4.models.port_settings_shared_port_product import PortSettingsSharedPortProduct
from equinix.services.fabricv4.models.port_sort_by import PortSortBy
from equinix.services.fabricv4.models.port_sort_criteria import PortSortCriteria
from equinix.services.fabricv4.models.port_sort_direction import PortSortDirection
from equinix.services.fabricv4.models.port_state import PortState
from equinix.services.fabricv4.models.port_tether import PortTether
from equinix.services.fabricv4.models.port_type import PortType
from equinix.services.fabricv4.models.port_v4_search_request import PortV4SearchRequest
from equinix.services.fabricv4.models.precision_time_change_operation import PrecisionTimeChangeOperation
from equinix.services.fabricv4.models.precision_time_change_operation_op import PrecisionTimeChangeOperationOp
from equinix.services.fabricv4.models.precision_time_change_operation_path import PrecisionTimeChangeOperationPath
from equinix.services.fabricv4.models.precision_time_order import PrecisionTimeOrder
from equinix.services.fabricv4.models.precision_time_package_request import PrecisionTimePackageRequest
from equinix.services.fabricv4.models.precision_time_package_request_code import PrecisionTimePackageRequestCode
from equinix.services.fabricv4.models.precision_time_package_response import PrecisionTimePackageResponse
from equinix.services.fabricv4.models.precision_time_package_response_type import PrecisionTimePackageResponseType
from equinix.services.fabricv4.models.precision_time_price import PrecisionTimePrice
from equinix.services.fabricv4.models.precision_time_service_connections_response import PrecisionTimeServiceConnectionsResponse
from equinix.services.fabricv4.models.precision_time_service_packages_response import PrecisionTimeServicePackagesResponse
from equinix.services.fabricv4.models.precision_time_service_request import PrecisionTimeServiceRequest
from equinix.services.fabricv4.models.precision_time_service_request_type import PrecisionTimeServiceRequestType
from equinix.services.fabricv4.models.precision_time_service_response import PrecisionTimeServiceResponse
from equinix.services.fabricv4.models.precision_time_service_response_state import PrecisionTimeServiceResponseState
from equinix.services.fabricv4.models.precision_time_service_response_type import PrecisionTimeServiceResponseType
from equinix.services.fabricv4.models.presence import Presence
from equinix.services.fabricv4.models.price import Price
from equinix.services.fabricv4.models.price_category import PriceCategory
from equinix.services.fabricv4.models.price_charge import PriceCharge
from equinix.services.fabricv4.models.price_charge_type import PriceChargeType
from equinix.services.fabricv4.models.price_error import PriceError
from equinix.services.fabricv4.models.price_error_additional_info import PriceErrorAdditionalInfo
from equinix.services.fabricv4.models.price_error_error_code import PriceErrorErrorCode
from equinix.services.fabricv4.models.price_error_error_message import PriceErrorErrorMessage
from equinix.services.fabricv4.models.price_location import PriceLocation
from equinix.services.fabricv4.models.price_search_response import PriceSearchResponse
from equinix.services.fabricv4.models.price_term_length import PriceTermLength
from equinix.services.fabricv4.models.process_step import ProcessStep
from equinix.services.fabricv4.models.product_type import ProductType
from equinix.services.fabricv4.models.project import Project
from equinix.services.fabricv4.models.provider_status import ProviderStatus
from equinix.services.fabricv4.models.ptp_advance_configuration import PtpAdvanceConfiguration
from equinix.services.fabricv4.models.ptp_advance_configuration_log_announce_interval import PtpAdvanceConfigurationLogAnnounceInterval
from equinix.services.fabricv4.models.ptp_advance_configuration_log_delay_req_interval import PtpAdvanceConfigurationLogDelayReqInterval
from equinix.services.fabricv4.models.ptp_advance_configuration_log_sync_interval import PtpAdvanceConfigurationLogSyncInterval
from equinix.services.fabricv4.models.ptp_advance_configuration_time_scale import PtpAdvanceConfigurationTimeScale
from equinix.services.fabricv4.models.ptp_advance_configuration_transport_mode import PtpAdvanceConfigurationTransportMode
from equinix.services.fabricv4.models.query_direction import QueryDirection
from equinix.services.fabricv4.models.remove_operation import RemoveOperation
from equinix.services.fabricv4.models.replace_operation import ReplaceOperation
from equinix.services.fabricv4.models.route_aggregation_change_data import RouteAggregationChangeData
from equinix.services.fabricv4.models.route_aggregation_change_data_response import RouteAggregationChangeDataResponse
from equinix.services.fabricv4.models.route_aggregation_connections_data import RouteAggregationConnectionsData
from equinix.services.fabricv4.models.route_aggregation_rule_state import RouteAggregationRuleState
from equinix.services.fabricv4.models.route_aggregation_rules_base import RouteAggregationRulesBase
from equinix.services.fabricv4.models.route_aggregation_rules_change import RouteAggregationRulesChange
from equinix.services.fabricv4.models.route_aggregation_rules_change_data import RouteAggregationRulesChangeData
from equinix.services.fabricv4.models.route_aggregation_rules_change_data_response import RouteAggregationRulesChangeDataResponse
from equinix.services.fabricv4.models.route_aggregation_rules_change_operation import RouteAggregationRulesChangeOperation
from equinix.services.fabricv4.models.route_aggregation_rules_change_type import RouteAggregationRulesChangeType
from equinix.services.fabricv4.models.route_aggregation_rules_data import RouteAggregationRulesData
from equinix.services.fabricv4.models.route_aggregation_rules_data_type import RouteAggregationRulesDataType
from equinix.services.fabricv4.models.route_aggregation_rules_patch_request_item import RouteAggregationRulesPatchRequestItem
from equinix.services.fabricv4.models.route_aggregation_rules_post_request import RouteAggregationRulesPostRequest
from equinix.services.fabricv4.models.route_aggregation_sort_item import RouteAggregationSortItem
from equinix.services.fabricv4.models.route_aggregation_sort_item_property import RouteAggregationSortItemProperty
from equinix.services.fabricv4.models.route_aggregation_state import RouteAggregationState
from equinix.services.fabricv4.models.route_aggregations_base import RouteAggregationsBase
from equinix.services.fabricv4.models.route_aggregations_base_type import RouteAggregationsBaseType
from equinix.services.fabricv4.models.route_aggregations_change import RouteAggregationsChange
from equinix.services.fabricv4.models.route_aggregations_change_operation import RouteAggregationsChangeOperation
from equinix.services.fabricv4.models.route_aggregations_change_type import RouteAggregationsChangeType
from equinix.services.fabricv4.models.route_aggregations_data import RouteAggregationsData
from equinix.services.fabricv4.models.route_aggregations_data_project import RouteAggregationsDataProject
from equinix.services.fabricv4.models.route_aggregations_patch_request_item import RouteAggregationsPatchRequestItem
from equinix.services.fabricv4.models.route_aggregations_search_base import RouteAggregationsSearchBase
from equinix.services.fabricv4.models.route_aggregations_search_base_filter import RouteAggregationsSearchBaseFilter
from equinix.services.fabricv4.models.route_aggregations_search_filter_item import RouteAggregationsSearchFilterItem
from equinix.services.fabricv4.models.route_aggregations_search_response import RouteAggregationsSearchResponse
from equinix.services.fabricv4.models.route_filter_change_data import RouteFilterChangeData
from equinix.services.fabricv4.models.route_filter_change_data_response import RouteFilterChangeDataResponse
from equinix.services.fabricv4.models.route_filter_connections_data import RouteFilterConnectionsData
from equinix.services.fabricv4.models.route_filter_rule_state import RouteFilterRuleState
from equinix.services.fabricv4.models.route_filter_rules_base import RouteFilterRulesBase
from equinix.services.fabricv4.models.route_filter_rules_change import RouteFilterRulesChange
from equinix.services.fabricv4.models.route_filter_rules_change_data import RouteFilterRulesChangeData
from equinix.services.fabricv4.models.route_filter_rules_change_data_response import RouteFilterRulesChangeDataResponse
from equinix.services.fabricv4.models.route_filter_rules_change_operation import RouteFilterRulesChangeOperation
from equinix.services.fabricv4.models.route_filter_rules_change_type import RouteFilterRulesChangeType
from equinix.services.fabricv4.models.route_filter_rules_data import RouteFilterRulesData
from equinix.services.fabricv4.models.route_filter_rules_data_action import RouteFilterRulesDataAction
from equinix.services.fabricv4.models.route_filter_rules_data_type import RouteFilterRulesDataType
from equinix.services.fabricv4.models.route_filter_rules_patch_request_item import RouteFilterRulesPatchRequestItem
from equinix.services.fabricv4.models.route_filter_rules_post_request import RouteFilterRulesPostRequest
from equinix.services.fabricv4.models.route_filter_state import RouteFilterState
from equinix.services.fabricv4.models.route_filters_base import RouteFiltersBase
from equinix.services.fabricv4.models.route_filters_base_type import RouteFiltersBaseType
from equinix.services.fabricv4.models.route_filters_change import RouteFiltersChange
from equinix.services.fabricv4.models.route_filters_change_operation import RouteFiltersChangeOperation
from equinix.services.fabricv4.models.route_filters_change_type import RouteFiltersChangeType
from equinix.services.fabricv4.models.route_filters_data import RouteFiltersData
from equinix.services.fabricv4.models.route_filters_data_not_matched_rule_action import RouteFiltersDataNotMatchedRuleAction
from equinix.services.fabricv4.models.route_filters_data_project import RouteFiltersDataProject
from equinix.services.fabricv4.models.route_filters_patch_request_item import RouteFiltersPatchRequestItem
from equinix.services.fabricv4.models.route_filters_search_base import RouteFiltersSearchBase
from equinix.services.fabricv4.models.route_filters_search_base_filter import RouteFiltersSearchBaseFilter
from equinix.services.fabricv4.models.route_filters_search_filter_item import RouteFiltersSearchFilterItem
from equinix.services.fabricv4.models.route_filters_search_filter_item_property import RouteFiltersSearchFilterItemProperty
from equinix.services.fabricv4.models.route_filters_search_response import RouteFiltersSearchResponse
from equinix.services.fabricv4.models.route_table_entry import RouteTableEntry
from equinix.services.fabricv4.models.route_table_entry_filter import RouteTableEntryFilter
from equinix.services.fabricv4.models.route_table_entry_filters import RouteTableEntryFilters
from equinix.services.fabricv4.models.route_table_entry_or_filter import RouteTableEntryOrFilter
from equinix.services.fabricv4.models.route_table_entry_protocol_type import RouteTableEntryProtocolType
from equinix.services.fabricv4.models.route_table_entry_search_request import RouteTableEntrySearchRequest
from equinix.services.fabricv4.models.route_table_entry_search_response import RouteTableEntrySearchResponse
from equinix.services.fabricv4.models.route_table_entry_simple_expression import RouteTableEntrySimpleExpression
from equinix.services.fabricv4.models.route_table_entry_sort_by import RouteTableEntrySortBy
from equinix.services.fabricv4.models.route_table_entry_sort_criteria import RouteTableEntrySortCriteria
from equinix.services.fabricv4.models.route_table_entry_sort_direction import RouteTableEntrySortDirection
from equinix.services.fabricv4.models.route_table_entry_state import RouteTableEntryState
from equinix.services.fabricv4.models.route_table_entry_type import RouteTableEntryType
from equinix.services.fabricv4.models.router_actions_connection import RouterActionsConnection
from equinix.services.fabricv4.models.router_package_code import RouterPackageCode
from equinix.services.fabricv4.models.routing_protocol_bfd import RoutingProtocolBFD
from equinix.services.fabricv4.models.routing_protocol_bgp_data import RoutingProtocolBGPData
from equinix.services.fabricv4.models.routing_protocol_bgp_data_state import RoutingProtocolBGPDataState
from equinix.services.fabricv4.models.routing_protocol_bgp_type import RoutingProtocolBGPType
from equinix.services.fabricv4.models.routing_protocol_bgp_type_type import RoutingProtocolBGPTypeType
from equinix.services.fabricv4.models.routing_protocol_base import RoutingProtocolBase
from equinix.services.fabricv4.models.routing_protocol_change import RoutingProtocolChange
from equinix.services.fabricv4.models.routing_protocol_change_data import RoutingProtocolChangeData
from equinix.services.fabricv4.models.routing_protocol_change_data_response import RoutingProtocolChangeDataResponse
from equinix.services.fabricv4.models.routing_protocol_change_operation import RoutingProtocolChangeOperation
from equinix.services.fabricv4.models.routing_protocol_change_operation_op import RoutingProtocolChangeOperationOp
from equinix.services.fabricv4.models.routing_protocol_change_type import RoutingProtocolChangeType
from equinix.services.fabricv4.models.routing_protocol_data import RoutingProtocolData
from equinix.services.fabricv4.models.routing_protocol_direct_data import RoutingProtocolDirectData
from equinix.services.fabricv4.models.routing_protocol_direct_type import RoutingProtocolDirectType
from equinix.services.fabricv4.models.routing_protocol_direct_type_type import RoutingProtocolDirectTypeType
from equinix.services.fabricv4.models.routing_protocol_operation import RoutingProtocolOperation
from equinix.services.fabricv4.models.search_expression import SearchExpression
from equinix.services.fabricv4.models.search_field_name import SearchFieldName
from equinix.services.fabricv4.models.search_request import SearchRequest
from equinix.services.fabricv4.models.search_response import SearchResponse
from equinix.services.fabricv4.models.service_metro import ServiceMetro
from equinix.services.fabricv4.models.service_metros import ServiceMetros
from equinix.services.fabricv4.models.service_profile import ServiceProfile
from equinix.services.fabricv4.models.service_profile_access_point_colo import ServiceProfileAccessPointCOLO
from equinix.services.fabricv4.models.service_profile_access_point_colo_type import ServiceProfileAccessPointCOLOType
from equinix.services.fabricv4.models.service_profile_access_point_type import ServiceProfileAccessPointType
from equinix.services.fabricv4.models.service_profile_access_point_type_colo import ServiceProfileAccessPointTypeCOLO
from equinix.services.fabricv4.models.service_profile_access_point_type_enum import ServiceProfileAccessPointTypeEnum
from equinix.services.fabricv4.models.service_profile_access_point_type_vd import ServiceProfileAccessPointTypeVD
from equinix.services.fabricv4.models.service_profile_access_point_vd import ServiceProfileAccessPointVD
from equinix.services.fabricv4.models.service_profile_access_point_vd_type import ServiceProfileAccessPointVDType
from equinix.services.fabricv4.models.service_profile_and_filter import ServiceProfileAndFilter
from equinix.services.fabricv4.models.service_profile_filter import ServiceProfileFilter
from equinix.services.fabricv4.models.service_profile_link_protocol_config import ServiceProfileLinkProtocolConfig
from equinix.services.fabricv4.models.service_profile_link_protocol_config_encapsulation import ServiceProfileLinkProtocolConfigEncapsulation
from equinix.services.fabricv4.models.service_profile_link_protocol_config_encapsulation_strategy import ServiceProfileLinkProtocolConfigEncapsulationStrategy
from equinix.services.fabricv4.models.service_profile_metadata import ServiceProfileMetadata
from equinix.services.fabricv4.models.service_profile_request import ServiceProfileRequest
from equinix.services.fabricv4.models.service_profile_search_request import ServiceProfileSearchRequest
from equinix.services.fabricv4.models.service_profile_simple_expression import ServiceProfileSimpleExpression
from equinix.services.fabricv4.models.service_profile_sort_by import ServiceProfileSortBy
from equinix.services.fabricv4.models.service_profile_sort_criteria import ServiceProfileSortCriteria
from equinix.services.fabricv4.models.service_profile_sort_direction import ServiceProfileSortDirection
from equinix.services.fabricv4.models.service_profile_state_enum import ServiceProfileStateEnum
from equinix.services.fabricv4.models.service_profile_type_enum import ServiceProfileTypeEnum
from equinix.services.fabricv4.models.service_profile_visibility_enum import ServiceProfileVisibilityEnum
from equinix.services.fabricv4.models.service_profiles import ServiceProfiles
from equinix.services.fabricv4.models.service_search_response import ServiceSearchResponse
from equinix.services.fabricv4.models.service_token import ServiceToken
from equinix.services.fabricv4.models.service_token_action_request import ServiceTokenActionRequest
from equinix.services.fabricv4.models.service_token_actions import ServiceTokenActions
from equinix.services.fabricv4.models.service_token_change_operation import ServiceTokenChangeOperation
from equinix.services.fabricv4.models.service_token_connection import ServiceTokenConnection
from equinix.services.fabricv4.models.service_token_connection_type import ServiceTokenConnectionType
from equinix.services.fabricv4.models.service_token_search_expression import ServiceTokenSearchExpression
from equinix.services.fabricv4.models.service_token_search_expression_operator import ServiceTokenSearchExpressionOperator
from equinix.services.fabricv4.models.service_token_search_field_name import ServiceTokenSearchFieldName
from equinix.services.fabricv4.models.service_token_search_request import ServiceTokenSearchRequest
from equinix.services.fabricv4.models.service_token_side import ServiceTokenSide
from equinix.services.fabricv4.models.service_token_state import ServiceTokenState
from equinix.services.fabricv4.models.service_token_type import ServiceTokenType
from equinix.services.fabricv4.models.service_tokens import ServiceTokens
from equinix.services.fabricv4.models.simplified_account import SimplifiedAccount
from equinix.services.fabricv4.models.simplified_link_protocol import SimplifiedLinkProtocol
from equinix.services.fabricv4.models.simplified_location import SimplifiedLocation
from equinix.services.fabricv4.models.simplified_location_without_ibx import SimplifiedLocationWithoutIBX
from equinix.services.fabricv4.models.simplified_metadata_entity import SimplifiedMetadataEntity
from equinix.services.fabricv4.models.simplified_network import SimplifiedNetwork
from equinix.services.fabricv4.models.simplified_network_change import SimplifiedNetworkChange
from equinix.services.fabricv4.models.simplified_notification import SimplifiedNotification
from equinix.services.fabricv4.models.simplified_notification_type import SimplifiedNotificationType
from equinix.services.fabricv4.models.simplified_port import SimplifiedPort
from equinix.services.fabricv4.models.simplified_service_profile import SimplifiedServiceProfile
from equinix.services.fabricv4.models.simplified_token_network import SimplifiedTokenNetwork
from equinix.services.fabricv4.models.simplified_token_network_scope import SimplifiedTokenNetworkScope
from equinix.services.fabricv4.models.simplified_token_network_type import SimplifiedTokenNetworkType
from equinix.services.fabricv4.models.simplified_virtual_device import SimplifiedVirtualDevice
from equinix.services.fabricv4.models.simplified_virtual_device_type import SimplifiedVirtualDeviceType
from equinix.services.fabricv4.models.sort import Sort
from equinix.services.fabricv4.models.sort_by import SortBy
from equinix.services.fabricv4.models.sort_criteria import SortCriteria
from equinix.services.fabricv4.models.sort_criteria_response import SortCriteriaResponse
from equinix.services.fabricv4.models.sort_direction import SortDirection
from equinix.services.fabricv4.models.sort_item import SortItem
from equinix.services.fabricv4.models.sort_item_direction import SortItemDirection
from equinix.services.fabricv4.models.sort_item_property import SortItemProperty
from equinix.services.fabricv4.models.statistics import Statistics
from equinix.services.fabricv4.models.statistics_view_point import StatisticsViewPoint
from equinix.services.fabricv4.models.stream import Stream
from equinix.services.fabricv4.models.stream_asset import StreamAsset
from equinix.services.fabricv4.models.stream_asset_attachment_status import StreamAssetAttachmentStatus
from equinix.services.fabricv4.models.stream_asset_filter import StreamAssetFilter
from equinix.services.fabricv4.models.stream_asset_filters import StreamAssetFilters
from equinix.services.fabricv4.models.stream_asset_or_filter import StreamAssetOrFilter
from equinix.services.fabricv4.models.stream_asset_put_request import StreamAssetPutRequest
from equinix.services.fabricv4.models.stream_asset_search_request import StreamAssetSearchRequest
from equinix.services.fabricv4.models.stream_asset_simple_expression import StreamAssetSimpleExpression
from equinix.services.fabricv4.models.stream_asset_sort_by import StreamAssetSortBy
from equinix.services.fabricv4.models.stream_asset_sort_criteria import StreamAssetSortCriteria
from equinix.services.fabricv4.models.stream_asset_sort_direction import StreamAssetSortDirection
from equinix.services.fabricv4.models.stream_asset_type import StreamAssetType
from equinix.services.fabricv4.models.stream_filter import StreamFilter
from equinix.services.fabricv4.models.stream_filter_or_filter import StreamFilterOrFilter
from equinix.services.fabricv4.models.stream_filter_simple_expression import StreamFilterSimpleExpression
from equinix.services.fabricv4.models.stream_get_subscriptions import StreamGetSubscriptions
from equinix.services.fabricv4.models.stream_get_subscriptions_type import StreamGetSubscriptionsType
from equinix.services.fabricv4.models.stream_post_request import StreamPostRequest
from equinix.services.fabricv4.models.stream_post_request_type import StreamPostRequestType
from equinix.services.fabricv4.models.stream_put_request import StreamPutRequest
from equinix.services.fabricv4.models.stream_subscription import StreamSubscription
from equinix.services.fabricv4.models.stream_subscription_filter import StreamSubscriptionFilter
from equinix.services.fabricv4.models.stream_subscription_post_request import StreamSubscriptionPostRequest
from equinix.services.fabricv4.models.stream_subscription_post_request_type import StreamSubscriptionPostRequestType
from equinix.services.fabricv4.models.stream_subscription_put_request import StreamSubscriptionPutRequest
from equinix.services.fabricv4.models.stream_subscription_selector import StreamSubscriptionSelector
from equinix.services.fabricv4.models.stream_subscription_sink import StreamSubscriptionSink
from equinix.services.fabricv4.models.stream_subscription_sink_credential import StreamSubscriptionSinkCredential
from equinix.services.fabricv4.models.stream_subscription_sink_credential_type import StreamSubscriptionSinkCredentialType
from equinix.services.fabricv4.models.stream_subscription_sink_setting import StreamSubscriptionSinkSetting
from equinix.services.fabricv4.models.stream_subscription_sink_type import StreamSubscriptionSinkType
from equinix.services.fabricv4.models.stream_subscription_state import StreamSubscriptionState
from equinix.services.fabricv4.models.stream_subscription_type import StreamSubscriptionType
from equinix.services.fabricv4.models.stream_target import StreamTarget
from equinix.services.fabricv4.models.sub_interface import SubInterface
from equinix.services.fabricv4.models.subscription_asset import SubscriptionAsset
from equinix.services.fabricv4.models.subscription_entitlement_response import SubscriptionEntitlementResponse
from equinix.services.fabricv4.models.subscription_response import SubscriptionResponse
from equinix.services.fabricv4.models.subscription_response_marketplace import SubscriptionResponseMarketplace
from equinix.services.fabricv4.models.subscription_response_offer_type import SubscriptionResponseOfferType
from equinix.services.fabricv4.models.subscription_router_package_type import SubscriptionRouterPackageType
from equinix.services.fabricv4.models.subscription_router_package_type_code import SubscriptionRouterPackageTypeCode
from equinix.services.fabricv4.models.subscription_state import SubscriptionState
from equinix.services.fabricv4.models.subscription_trial import SubscriptionTrial
from equinix.services.fabricv4.models.time_service_filter import TimeServiceFilter
from equinix.services.fabricv4.models.time_service_filters import TimeServiceFilters
from equinix.services.fabricv4.models.time_service_or_filter import TimeServiceOrFilter
from equinix.services.fabricv4.models.time_service_price import TimeServicePrice
from equinix.services.fabricv4.models.time_service_price_connection import TimeServicePriceConnection
from equinix.services.fabricv4.models.time_service_price_connection_a_side import TimeServicePriceConnectionASide
from equinix.services.fabricv4.models.time_service_price_connection_access_point import TimeServicePriceConnectionAccessPoint
from equinix.services.fabricv4.models.time_service_simple_expression import TimeServiceSimpleExpression
from equinix.services.fabricv4.models.time_service_sort_by import TimeServiceSortBy
from equinix.services.fabricv4.models.time_service_sort_criteria import TimeServiceSortCriteria
from equinix.services.fabricv4.models.time_service_sort_direction import TimeServiceSortDirection
from equinix.services.fabricv4.models.time_services_search_request import TimeServicesSearchRequest
from equinix.services.fabricv4.models.top_utilized_statistics import TopUtilizedStatistics
from equinix.services.fabricv4.models.validate_connection_response import ValidateConnectionResponse
from equinix.services.fabricv4.models.validate_request import ValidateRequest
from equinix.services.fabricv4.models.validate_request_filter import ValidateRequestFilter
from equinix.services.fabricv4.models.validate_request_filter_and import ValidateRequestFilterAnd
from equinix.services.fabricv4.models.validate_subnet_response import ValidateSubnetResponse
from equinix.services.fabricv4.models.view_point import ViewPoint
from equinix.services.fabricv4.models.virtual_connection_bridge_package_code import VirtualConnectionBridgePackageCode
from equinix.services.fabricv4.models.virtual_connection_price import VirtualConnectionPrice
from equinix.services.fabricv4.models.virtual_connection_price_a_side import VirtualConnectionPriceASide
from equinix.services.fabricv4.models.virtual_connection_price_a_side_access_point import VirtualConnectionPriceASideAccessPoint
from equinix.services.fabricv4.models.virtual_connection_price_a_side_access_point_port import VirtualConnectionPriceASideAccessPointPort
from equinix.services.fabricv4.models.virtual_connection_price_a_side_access_point_port_settings import VirtualConnectionPriceASideAccessPointPortSettings
from equinix.services.fabricv4.models.virtual_connection_price_access_point_type import VirtualConnectionPriceAccessPointType
from equinix.services.fabricv4.models.virtual_connection_price_connection_type import VirtualConnectionPriceConnectionType
from equinix.services.fabricv4.models.virtual_connection_price_z_side import VirtualConnectionPriceZSide
from equinix.services.fabricv4.models.virtual_connection_price_z_side_access_point import VirtualConnectionPriceZSideAccessPoint
from equinix.services.fabricv4.models.virtual_connection_price_z_side_access_point_bridge import VirtualConnectionPriceZSideAccessPointBridge
from equinix.services.fabricv4.models.virtual_connection_price_z_side_access_point_bridge_package import VirtualConnectionPriceZSideAccessPointBridgePackage
from equinix.services.fabricv4.models.virtual_connection_price_z_side_access_point_profile import VirtualConnectionPriceZSideAccessPointProfile
from equinix.services.fabricv4.models.virtual_connection_side import VirtualConnectionSide
from equinix.services.fabricv4.models.virtual_connection_time_service_response import VirtualConnectionTimeServiceResponse
from equinix.services.fabricv4.models.virtual_connection_uuid import VirtualConnectionUuid
from equinix.services.fabricv4.models.virtual_device import VirtualDevice
from equinix.services.fabricv4.models.virtual_device_interface import VirtualDeviceInterface
from equinix.services.fabricv4.models.virtual_device_interface_type import VirtualDeviceInterfaceType
from equinix.services.fabricv4.models.virtual_device_type import VirtualDeviceType
from equinix.services.fabricv4.models.virtual_network import VirtualNetwork
from equinix.services.fabricv4.models.virtual_port_configuration import VirtualPortConfiguration
from equinix.services.fabricv4.models.virtual_port_location import VirtualPortLocation
from equinix.services.fabricv4.models.virtual_port_price import VirtualPortPrice
from equinix.services.fabricv4.models.virtual_port_redundancy import VirtualPortRedundancy
from equinix.services.fabricv4.models.virtual_port_service_type import VirtualPortServiceType
from equinix.services.fabricv4.models.virtual_port_type import VirtualPortType
from equinix.services.fabricv4.models.vpic_interface import VpicInterface



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.batches_api import BatchesApi


class TestBatchesApi(unittest.TestCase):
    """BatchesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BatchesApi()

    def tearDown(self) -> None:
        pass

    def test_create_device_batch(self) -> None:
        """Test case for create_device_batch

        Create a devices batch
        """
        pass

    def test_delete_batch(self) -> None:
        """Test case for delete_batch

        Delete the Batch
        """
        pass

    def test_find_batch_by_id(self) -> None:
        """Test case for find_batch_by_id

        Retrieve a Batch
        """
        pass

    def test_find_batches_by_project(self) -> None:
        """Test case for find_batches_by_project

        Retrieve all batches by project
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.ip_addresses_api import IPAddressesApi


class TestIPAddressesApi(unittest.TestCase):
    """IPAddressesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IPAddressesApi()

    def tearDown(self) -> None:
        pass

    def test_delete_ip_address(self) -> None:
        """Test case for delete_ip_address

        Unassign an ip address
        """
        pass

    def test_find_ip_address_by_id(self) -> None:
        """Test case for find_ip_address_by_id

        Retrieve an ip address
        """
        pass

    def test_find_ip_address_customdata(self) -> None:
        """Test case for find_ip_address_customdata

        Retrieve the custom metadata of an IP Reservation or IP Assignment
        """
        pass

    def test_find_ip_availabilities(self) -> None:
        """Test case for find_ip_availabilities

        Retrieve all available subnets of a particular reservation
        """
        pass

    def test_find_ip_reservations(self) -> None:
        """Test case for find_ip_reservations

        Retrieve all ip reservations
        """
        pass

    def test_request_ip_reservation(self) -> None:
        """Test case for request_ip_reservation

        Requesting IP reservations
        """
        pass

    def test_update_ip_address(self) -> None:
        """Test case for update_ip_address

        Update an ip address
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.user_limited import UserLimited

class TestUserLimited(unittest.TestCase):
    """UserLimited unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserLimited:
        """Test UserLimited
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserLimited`
        """
        model = UserLimited()
        if include_optional:
            return UserLimited(
                avatar_thumb_url = '',
                avatar_url = '',
                full_name = '',
                href = '',
                id = ''
            )
        else:
            return UserLimited(
                id = '',
        )
        """

    def testUserLimited(self):
        """Test UserLimited"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.password_reset_tokens_api import PasswordResetTokensApi


class TestPasswordResetTokensApi(unittest.TestCase):
    """PasswordResetTokensApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PasswordResetTokensApi()

    def tearDown(self) -> None:
        pass

    def test_create_password_reset_token(self) -> None:
        """Test case for create_password_reset_token

        Create a password reset token
        """
        pass

    def test_reset_password(self) -> None:
        """Test case for reset_password

        Reset current user password
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from equinix.services.metalv1.models.bgp_route import BgpRoute
from typing import Optional, Set
from typing_extensions import Self

class BgpNeighborData(BaseModel):
    """
    BgpNeighborData
    """ # noqa: E501
    address_family: Optional[StrictInt] = Field(default=None, description="Address Family for IP Address. Accepted values are 4 or 6")
    customer_as: Optional[StrictInt] = Field(default=None, description="The customer's ASN. In a local BGP deployment, this will be an internal ASN used to route within the data center. For a global BGP deployment, this will be the your own ASN, configured when you set up BGP for your project.")
    customer_ip: Optional[StrictStr] = Field(default=None, description="The device's IP address. For an IPv4 BGP session, this is typically the private bond0 address for the device.")
    href: Optional[StrictStr] = None
    md5_enabled: Optional[StrictBool] = Field(default=None, description="True if an MD5 password is configured for the project.")
    md5_password: Optional[StrictStr] = Field(default=None, description="The MD5 password configured for the project, if set.")
    multihop: Optional[StrictBool] = Field(default=None, description="True when the BGP session should be configured as multihop.")
    peer_as: Optional[StrictInt] = Field(default=None, description="The Peer ASN to use when configuring BGP on your device.")
    peer_ips: Optional[List[StrictStr]] = Field(default=None, description="A list of one or more IP addresses to use for the Peer IP section of your BGP configuration. For non-multihop sessions, this will typically be a single gateway address for the device. For multihop sessions, it will be a list of IPs.")
    routes_in: Optional[List[BgpRoute]] = Field(default=None, description="A list of project subnets")
    routes_out: Optional[List[BgpRoute]] = Field(default=None, description="A list of outgoing routes. Only populated if the BGP session has default route enabled.")
    __properties: ClassVar[List[str]] = ["address_family", "customer_as", "customer_ip", "href", "md5_enabled", "md5_password", "multihop", "peer_as", "peer_ips", "routes_in", "routes_out"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BgpNeighborData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in routes_in (list)
        _items = []
        if self.routes_in:
            for _item in self.routes_in:
                if _item:
                    _items.append(_item.to_dict())
            _dict['routes_in'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in routes_out (list)
        _items = []
        if self.routes_out:
            for _item in self.routes_out:
                if _item:
                    _items.append(_item.to_dict())
            _dict['routes_out'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BgpNeighborData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "address_family": obj.get("address_family"),
            "customer_as": obj.get("customer_as"),
            "customer_ip": obj.get("customer_ip"),
            "href": obj.get("href"),
            "md5_enabled": obj.get("md5_enabled"),
            "md5_password": obj.get("md5_password"),
            "multihop": obj.get("multihop"),
            "peer_as": obj.get("peer_as"),
            "peer_ips": obj.get("peer_ips"),
            "routes_in": [BgpRoute.from_dict(_item) for _item in obj["routes_in"]] if obj.get("routes_in") is not None else None,
            "routes_out": [BgpRoute.from_dict(_item) for _item in obj["routes_out"]] if obj.get("routes_out") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.transfer_requests_api import TransferRequestsApi


class TestTransferRequestsApi(unittest.TestCase):
    """TransferRequestsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TransferRequestsApi()

    def tearDown(self) -> None:
        pass

    def test_accept_transfer_request(self) -> None:
        """Test case for accept_transfer_request

        Accept a transfer request
        """
        pass

    def test_decline_transfer_request(self) -> None:
        """Test case for decline_transfer_request

        Decline a transfer request
        """
        pass

    def test_find_transfer_request_by_id(self) -> None:
        """Test case for find_transfer_request_by_id

        View a transfer request
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.auth_token_project import AuthTokenProject

class TestAuthTokenProject(unittest.TestCase):
    """AuthTokenProject unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthTokenProject:
        """Test AuthTokenProject
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthTokenProject`
        """
        model = AuthTokenProject()
        if include_optional:
            return AuthTokenProject(
                backend_transfer_enabled = True,
                bgp_config = equinix.services.metalv1.models.href.Href(
                    href = '', ),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                customdata = equinix.services.metalv1.models.customdata.customdata(),
                devices = [
                    equinix.services.metalv1.models.href.Href(
                        href = '', )
                    ],
                href = '',
                id = '',
                invitations = [
                    equinix.services.metalv1.models.href.Href(
                        href = '', )
                    ],
                max_devices = equinix.services.metalv1.models.max_devices.max_devices(),
                members = [
                    equinix.services.metalv1.models.href.Href(
                        href = '', )
                    ],
                memberships = [
                    equinix.services.metalv1.models.href.Href(
                        href = '', )
                    ],
                name = '0',
                network_status = equinix.services.metalv1.models.network_status.network_status(),
                organization = equinix.services.metalv1.models.href.Href(
                    href = '', ),
                payment_method = equinix.services.metalv1.models.href.Href(
                    href = '', ),
                ssh_keys = [
                    equinix.services.metalv1.models.href.Href(
                        href = '', )
                    ],
                tags = [
                    ''
                    ],
                type = 'default',
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                url = '',
                volumes = [
                    equinix.services.metalv1.models.href.Href(
                        href = '', )
                    ]
            )
        else:
            return AuthTokenProject(
        )
        """

    def testAuthTokenProject(self):
        """Test AuthTokenProject"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.component import Component

class TestComponent(unittest.TestCase):
    """Component unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Component:
        """Test Component
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Component`
        """
        model = Component()
        if include_optional:
            return Component(
                checksum = '',
                component = 'bmc',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                filename = '',
                href = '',
                model = [
                    'romed8hm3'
                    ],
                repository_url = '',
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                upstream_url = '',
                uuid = '0516463a-47ee-4809-9a66-ece8c740eed9',
                vendor = 'equinix',
                version = '1.5.0'
            )
        else:
            return Component(
        )
        """

    def testComponent(self):
        """Test Component"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.invoice_list import InvoiceList

class TestInvoiceList(unittest.TestCase):
    """InvoiceList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvoiceList:
        """Test InvoiceList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InvoiceList`
        """
        model = InvoiceList()
        if include_optional:
            return InvoiceList(
                href = '',
                invoices = [
                    equinix.services.metalv1.models.invoice.Invoice(
                        amount = 1.337, 
                        balance = 1.337, 
                        created_on = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        credit_amount = 1.337, 
                        credits_applied = 1.337, 
                        currency = 'USD', 
                        due_on = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        href = '', 
                        id = '', 
                        items = [
                            equinix.services.metalv1.models.line_item.LineItem(
                                adjustments = [
                                    equinix.services.metalv1.models.line_item_adjustment.LineItemAdjustment(
                                        amount = 1.337, 
                                        description = '', 
                                        href = '', )
                                    ], 
                                amount = 1.337, 
                                currency = '', 
                                description = '', 
                                details = '', 
                                end_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                hostname = '', 
                                href = '', 
                                item_type = '', 
                                location = '', 
                                plan = equinix.services.metalv1.models.plan_id_name.PlanIdName(
                                    href = '', 
                                    id = '', 
                                    name = '', ), 
                                plan_id = '', 
                                project = equinix.services.metalv1.models.project_id_name.ProjectIdName(
                                    href = '', 
                                    id = '', 
                                    name = '', ), 
                                project_id = '', 
                                service_id = '', 
                                start_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                unit = '', 
                                unit_price = 1.337, )
                            ], 
                        number = '', 
                        project = equinix.services.metalv1.models.project_id_name.ProjectIdName(
                            href = '', 
                            id = '', 
                            name = '', ), 
                        reference_number = '', 
                        status = '', 
                        target_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), )
                    ]
            )
        else:
            return InvoiceList(
        )
        """

    def testInvoiceList(self):
        """Test InvoiceList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.user_create_input import UserCreateInput

class TestUserCreateInput(unittest.TestCase):
    """UserCreateInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserCreateInput:
        """Test UserCreateInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserCreateInput`
        """
        model = UserCreateInput()
        if include_optional:
            return UserCreateInput(
                company_name = '',
                company_url = '',
                customdata = None,
                emails = [
                    equinix.services.metalv1.models.email_input.EmailInput(
                        address = '', 
                        default = True, 
                        href = '', )
                    ],
                first_name = '',
                href = '',
                invitation_id = '',
                last_name = '',
                level = '',
                nonce = '',
                password = '',
                phone_number = '',
                social_accounts = None,
                timezone = '',
                title = '',
                two_factor_auth = '',
                verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return UserCreateInput(
                emails = [
                    equinix.services.metalv1.models.email_input.EmailInput(
                        address = '', 
                        default = True, 
                        href = '', )
                    ],
                first_name = '',
                last_name = '',
        )
        """

    def testUserCreateInput(self):
        """Test UserCreateInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.interconnection_list import InterconnectionList

class TestInterconnectionList(unittest.TestCase):
    """InterconnectionList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InterconnectionList:
        """Test InterconnectionList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InterconnectionList`
        """
        model = InterconnectionList()
        if include_optional:
            return InterconnectionList(
                href = '',
                interconnections = [
                    equinix.services.metalv1.models.interconnection.Interconnection(
                        authorization_code = '', 
                        contact_email = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        fabric_provider = null, 
                        facility = equinix.services.metalv1.models.facility.Facility(
                            address = equinix.services.metalv1.models.address.Address(
                                address2 = '', 
                                city = '', 
                                coordinates = equinix.services.metalv1.models.coordinates.Coordinates(
                                    href = '', 
                                    latitude = '', 
                                    longitude = '', ), 
                                country = '', 
                                href = '', 
                                state = '', 
                                zip_code = '', ), 
                            code = '', 
                            features = ["baremetal","backend_transfer","global_ipv4"], 
                            href = '', 
                            id = '', 
                            ip_ranges = ["2604:1380::/36","147.75.192.0/21"], 
                            metro = null, 
                            name = '', ), 
                        href = '', 
                        id = '', 
                        metro = null, 
                        mode = 'standard', 
                        name = '', 
                        organization = equinix.services.metalv1.models.organization.Organization(
                            billing_address = equinix.services.metalv1.models.address.Address(
                                address2 = '', 
                                city = '', 
                                country = '', 
                                href = '', 
                                state = '', 
                                zip_code = '', ), 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            credit_amount = 1.337, 
                            customdata = equinix.services.metalv1.models.customdata.customdata(), 
                            description = '', 
                            enforce_2fa_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            href = '', 
                            id = '', 
                            logo = '', 
                            members = [
                                equinix.services.metalv1.models.href.Href(
                                    href = '', )
                                ], 
                            memberships = [
                                equinix.services.metalv1.models.href.Href(
                                    href = '', )
                                ], 
                            name = '', 
                            projects = [
                                
                                ], 
                            terms = 56, 
                            twitter = '', 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            website = '', ), 
                        ports = [
                            equinix.services.metalv1.models.interconnection_port.InterconnectionPort(
                                href = '', 
                                id = '', 
                                link_status = '', 
                                name = '', 
                                role = 'primary', 
                                speed = 56, 
                                status = 'requested', 
                                switch_id = '', 
                                virtual_circuits = [
                                    null
                                    ], )
                            ], 
                        project = equinix.services.metalv1.models.project.Project(
                            backend_transfer_enabled = True, 
                            bgp_config = , 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            customdata = equinix.services.metalv1.models.customdata.customdata(), 
                            devices = [
                                
                                ], 
                            href = '', 
                            id = '', 
                            invitations = [
                                
                                ], 
                            max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                            name = '0', 
                            network_status = equinix.services.metalv1.models.network_status.network_status(), 
                            payment_method = , 
                            ssh_keys = [
                                
                                ], 
                            tags = [
                                ''
                                ], 
                            type = 'default', 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            url = '', 
                            volumes = [
                                
                                ], ), 
                        redundancy = 'primary', 
                        requested_by = , 
                        service_tokens = [
                            equinix.services.metalv1.models.fabric_service_token.FabricServiceToken(
                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                href = '', 
                                id = '', 
                                max_allowed_speed = 10000000000, 
                                role = 'primary', 
                                service_token_type = 'a_side', 
                                state = 'inactive', )
                            ], 
                        speed = 10000000000, 
                        status = '', 
                        tags = [
                            ''
                            ], 
                        token = '', 
                        type = 'shared', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                meta = equinix.services.metalv1.models.meta.Meta(
                    current_page = 56, 
                    first = equinix.services.metalv1.models.href.Href(
                        href = '', ), 
                    href = '', 
                    last = equinix.services.metalv1.models.href.Href(
                        href = '', ), 
                    last_page = 56, 
                    next = , 
                    previous = , 
                    self = , 
                    total = 56, )
            )
        else:
            return InterconnectionList(
        )
        """

    def testInterconnectionList(self):
        """Test InterconnectionList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from equinix.services.metalv1.models.href import Href
from equinix.services.metalv1.models.metal_gateway_lite import MetalGatewayLite
from equinix.services.metalv1.models.metro import Metro
from equinix.services.metalv1.models.project import Project
from typing import Optional, Set
from typing_extensions import Self

class VirtualNetwork(BaseModel):
    """
    VirtualNetwork
    """ # noqa: E501
    assigned_to: Optional[Project] = None
    assigned_to_virtual_circuit: Optional[StrictBool] = Field(default=None, description="True if the virtual network is attached to a virtual circuit. False if not.")
    created_at: Optional[datetime] = None
    description: Optional[StrictStr] = None
    facility: Optional[Href] = None
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    instances: Optional[List[Device]] = Field(default=None, description="A list of instances with ports currently associated to this Virtual Network.")
    metal_gateways: Optional[List[MetalGatewayLite]] = Field(default=None, description="A list of metal gateways currently associated to this Virtual Network.")
    metro: Optional[Metro] = None
    metro_code: Optional[StrictStr] = Field(default=None, description="The Metro code of the metro in which this Virtual Network is defined.")
    tags: Optional[List[StrictStr]] = None
    vxlan: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["assigned_to", "assigned_to_virtual_circuit", "created_at", "description", "facility", "href", "id", "instances", "metal_gateways", "metro", "metro_code", "tags", "vxlan"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VirtualNetwork from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of assigned_to
        if self.assigned_to:
            _dict['assigned_to'] = self.assigned_to.to_dict()
        # override the default output from pydantic by calling `to_dict()` of facility
        if self.facility:
            _dict['facility'] = self.facility.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in instances (list)
        _items = []
        if self.instances:
            for _item in self.instances:
                if _item:
                    _items.append(_item.to_dict())
            _dict['instances'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in metal_gateways (list)
        _items = []
        if self.metal_gateways:
            for _item in self.metal_gateways:
                if _item:
                    _items.append(_item.to_dict())
            _dict['metal_gateways'] = _items
        # override the default output from pydantic by calling `to_dict()` of metro
        if self.metro:
            _dict['metro'] = self.metro.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VirtualNetwork from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "assigned_to": Project.from_dict(obj["assigned_to"]) if obj.get("assigned_to") is not None else None,
            "assigned_to_virtual_circuit": obj.get("assigned_to_virtual_circuit"),
            "created_at": obj.get("created_at"),
            "description": obj.get("description"),
            "facility": Href.from_dict(obj["facility"]) if obj.get("facility") is not None else None,
            "href": obj.get("href"),
            "id": obj.get("id"),
            "instances": [Device.from_dict(_item) for _item in obj["instances"]] if obj.get("instances") is not None else None,
            "metal_gateways": [MetalGatewayLite.from_dict(_item) for _item in obj["metal_gateways"]] if obj.get("metal_gateways") is not None else None,
            "metro": Metro.from_dict(obj["metro"]) if obj.get("metro") is not None else None,
            "metro_code": obj.get("metro_code"),
            "tags": obj.get("tags"),
            "vxlan": obj.get("vxlan")
        })
        return _obj

from equinix.services.metalv1.models.device import Device
# TODO: Rewrite to not use raise_errors
VirtualNetwork.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class MetalGatewayLite(BaseModel):
    """
    MetalGatewayLite
    """ # noqa: E501
    created_at: Optional[datetime] = None
    gateway_address: Optional[StrictStr] = Field(default=None, description="The gateway address with subnet CIDR value for this Metal Gateway. For example, a Metal Gateway using an IP reservation with block 10.1.2.0/27 would have a gateway address of 10.1.2.1/27.")
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    state: Optional[StrictStr] = Field(default=None, description="The current state of the Metal Gateway. 'Ready' indicates the gateway record has been configured, but is currently not active on the network. 'Active' indicates the gateway has been configured on the network. 'Deleting' is a temporary state used to indicate that the gateway is in the process of being un-configured from the network, after which the gateway record will be deleted.")
    updated_at: Optional[datetime] = None
    vlan: Optional[StrictInt] = Field(default=None, description="The VLAN id of the Virtual Network record associated to this Metal Gateway.")
    __properties: ClassVar[List[str]] = ["created_at", "gateway_address", "href", "id", "state", "updated_at", "vlan"]

    @field_validator('state')
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['ready', 'active', 'deleting']):
            raise ValueError("must be one of enum values ('ready', 'active', 'deleting')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MetalGatewayLite from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MetalGatewayLite from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "created_at": obj.get("created_at"),
            "gateway_address": obj.get("gateway_address"),
            "href": obj.get("href"),
            "id": obj.get("id"),
            "state": obj.get("state"),
            "updated_at": obj.get("updated_at"),
            "vlan": obj.get("vlan")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.self_service_reservation_item_response import SelfServiceReservationItemResponse

class TestSelfServiceReservationItemResponse(unittest.TestCase):
    """SelfServiceReservationItemResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SelfServiceReservationItemResponse:
        """Test SelfServiceReservationItemResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SelfServiceReservationItemResponse`
        """
        model = SelfServiceReservationItemResponse()
        if include_optional:
            return SelfServiceReservationItemResponse(
                amount = 1.337,
                href = '',
                id = '',
                metro_code = '',
                metro_id = '',
                metro_name = '',
                plan = equinix.services.metalv1.models.plan.Plan(
                    available_in = [
                        equinix.services.metalv1.models.plan_available_in_inner.Plan_available_in_inner(
                            href = '', 
                            price = equinix.services.metalv1.models.plan_available_in_inner_price.Plan_available_in_inner_price(
                                hour = 1.23, 
                                href = '', ), )
                        ], 
                    available_in_metros = [
                        equinix.services.metalv1.models.plan_available_in_metros_inner.Plan_available_in_metros_inner(
                            href = '', )
                        ], 
                    categories = [
                        ''
                        ], 
                    class = 'm3.large.x86', 
                    deployment_types = [
                        'on_demand'
                        ], 
                    description = '', 
                    href = '', 
                    id = '', 
                    legacy = True, 
                    line = '', 
                    name = '', 
                    pricing = equinix.services.metalv1.models.pricing.pricing(), 
                    slug = 'm3.large.x86', 
                    specs = equinix.services.metalv1.models.plan_specs.Plan_specs(
                        cpus = [
                            equinix.services.metalv1.models.plan_specs_cpus_inner.Plan_specs_cpus_inner(
                                count = 56, 
                                href = '', 
                                type = '', )
                            ], 
                        drives = [
                            equinix.services.metalv1.models.plan_specs_drives_inner.Plan_specs_drives_inner(
                                category = '', 
                                count = 56, 
                                href = '', 
                                size = '3.84TB', 
                                type = '', )
                            ], 
                        features = equinix.services.metalv1.models.plan_specs_features.Plan_specs_features(
                            href = '', 
                            raid = True, 
                            txt = True, 
                            uefi = True, ), 
                        href = '', 
                        memory = equinix.services.metalv1.models.plan_specs_memory.Plan_specs_memory(
                            href = '', 
                            total = '', ), 
                        nics = [
                            equinix.services.metalv1.models.plan_specs_nics_inner.Plan_specs_nics_inner(
                                count = 2, 
                                href = '', 
                                type = '', )
                            ], ), 
                    type = 'standard', ),
                plan_categories = [
                    ''
                    ],
                plan_id = '',
                plan_name = '',
                plan_slug = '',
                quantity = 56,
                term = ''
            )
        else:
            return SelfServiceReservationItemResponse(
        )
        """

    def testSelfServiceReservationItemResponse(self):
        """Test SelfServiceReservationItemResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.self_service_reservation_list import SelfServiceReservationList

class TestSelfServiceReservationList(unittest.TestCase):
    """SelfServiceReservationList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SelfServiceReservationList:
        """Test SelfServiceReservationList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SelfServiceReservationList`
        """
        model = SelfServiceReservationList()
        if include_optional:
            return SelfServiceReservationList(
                href = '',
                reservations = [
                    equinix.services.metalv1.models.self_service_reservation_response.SelfServiceReservationResponse(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        href = '', 
                        item = [
                            equinix.services.metalv1.models.self_service_reservation_item_response.SelfServiceReservationItemResponse(
                                amount = 1.337, 
                                href = '', 
                                id = '', 
                                metro_code = '', 
                                metro_id = '', 
                                metro_name = '', 
                                plan = equinix.services.metalv1.models.plan.Plan(
                                    available_in = [
                                        equinix.services.metalv1.models.plan_available_in_inner.Plan_available_in_inner(
                                            href = '', 
                                            price = equinix.services.metalv1.models.plan_available_in_inner_price.Plan_available_in_inner_price(
                                                hour = 1.23, 
                                                href = '', ), )
                                        ], 
                                    available_in_metros = [
                                        equinix.services.metalv1.models.plan_available_in_metros_inner.Plan_available_in_metros_inner(
                                            href = '', )
                                        ], 
                                    categories = [
                                        ''
                                        ], 
                                    class = 'm3.large.x86', 
                                    deployment_types = [
                                        'on_demand'
                                        ], 
                                    description = '', 
                                    href = '', 
                                    id = '', 
                                    legacy = True, 
                                    line = '', 
                                    name = '', 
                                    pricing = equinix.services.metalv1.models.pricing.pricing(), 
                                    slug = 'm3.large.x86', 
                                    specs = equinix.services.metalv1.models.plan_specs.Plan_specs(
                                        cpus = [
                                            equinix.services.metalv1.models.plan_specs_cpus_inner.Plan_specs_cpus_inner(
                                                count = 56, 
                                                href = '', 
                                                type = '', )
                                            ], 
                                        drives = [
                                            equinix.services.metalv1.models.plan_specs_drives_inner.Plan_specs_drives_inner(
                                                category = '', 
                                                count = 56, 
                                                href = '', 
                                                size = '3.84TB', 
                                                type = '', )
                                            ], 
                                        features = equinix.services.metalv1.models.plan_specs_features.Plan_specs_features(
                                            href = '', 
                                            raid = True, 
                                            txt = True, 
                                            uefi = True, ), 
                                        href = '', 
                                        memory = equinix.services.metalv1.models.plan_specs_memory.Plan_specs_memory(
                                            href = '', 
                                            total = '', ), 
                                        nics = [
                                            equinix.services.metalv1.models.plan_specs_nics_inner.Plan_specs_nics_inner(
                                                count = 2, 
                                                href = '', 
                                                type = '', )
                                            ], ), 
                                    type = 'standard', ), 
                                plan_categories = [
                                    ''
                                    ], 
                                plan_id = '', 
                                plan_name = '', 
                                plan_slug = '', 
                                quantity = 56, 
                                term = '', )
                            ], 
                        notes = '', 
                        organization = '', 
                        organization_id = '', 
                        period = equinix.services.metalv1.models.create_self_service_reservation_request_period.CreateSelfServiceReservationRequest_period(
                            count = 12, 
                            href = '', 
                            unit = 'monthly', ), 
                        project = '', 
                        project_id = '', 
                        start_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        status = '', 
                        total_cost = 56, )
                    ]
            )
        else:
            return SelfServiceReservationList(
        )
        """

    def testSelfServiceReservationList(self):
        """Test SelfServiceReservationList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.spot_market_prices_list import SpotMarketPricesList

class TestSpotMarketPricesList(unittest.TestCase):
    """SpotMarketPricesList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpotMarketPricesList:
        """Test SpotMarketPricesList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpotMarketPricesList`
        """
        model = SpotMarketPricesList()
        if include_optional:
            return SpotMarketPricesList(
                href = '',
                spot_market_prices = equinix.services.metalv1.models.spot_prices_report.SpotPricesReport(
                    ams1 = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                        baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                            href = '', 
                            price = 1.337, ), 
                        baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                            href = '', 
                            price = 1.337, ), 
                        baremetal_2 = , 
                        baremetal_2a = , 
                        baremetal_2a2 = , 
                        baremetal_3 = , 
                        baremetal_s = , 
                        c2/medium/x86 = , 
                        href = '', 
                        m2/xlarge/x86 = , ), 
                    atl1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                        baremetal_1e = , 
                        href = '', ), 
                    dfw1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                        href = '', ), 
                    ewr1 = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                        href = '', ), 
                    fra1 = , 
                    href = '', 
                    iad1 = , 
                    lax1 = , 
                    nrt1 = , 
                    ord1 = , 
                    sea1 = , 
                    sin1 = , 
                    sjc1 = , 
                    syd1 = , 
                    yyz1 = , )
            )
        else:
            return SpotMarketPricesList(
        )
        """

    def testSpotMarketPricesList(self):
        """Test SpotMarketPricesList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.hardware_reservations_api import HardwareReservationsApi


class TestHardwareReservationsApi(unittest.TestCase):
    """HardwareReservationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = HardwareReservationsApi()

    def tearDown(self) -> None:
        pass

    def test_activate_hardware_reservation(self) -> None:
        """Test case for activate_hardware_reservation

        Activate a spare hardware reservation
        """
        pass

    def test_find_hardware_reservation_by_id(self) -> None:
        """Test case for find_hardware_reservation_by_id

        Retrieve a hardware reservation
        """
        pass

    def test_find_project_hardware_reservations(self) -> None:
        """Test case for find_project_hardware_reservations

        Retrieve all hardware reservations for a given project
        """
        pass

    def test_find_project_hardware_reservations_all_pages(self):
        """Test case for find_project_hardware_reservations_all_pages

        Retrieve all hardware reservations for a given project  # noqa: E501
        """
        pass

    def test_move_hardware_reservation(self) -> None:
        """Test case for move_hardware_reservation

        Move a hardware reservation
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from equinix.services.metalv1.models.create_self_service_reservation_request_period import CreateSelfServiceReservationRequestPeriod
from equinix.services.metalv1.models.self_service_reservation_item_response import SelfServiceReservationItemResponse
from typing import Optional, Set
from typing_extensions import Self

class SelfServiceReservationResponse(BaseModel):
    """
    SelfServiceReservationResponse
    """ # noqa: E501
    created_at: Optional[datetime] = None
    href: Optional[StrictStr] = None
    item: Optional[List[SelfServiceReservationItemResponse]] = None
    notes: Optional[StrictStr] = None
    organization: Optional[StrictStr] = None
    organization_id: Optional[StrictStr] = None
    period: Optional[CreateSelfServiceReservationRequestPeriod] = None
    project: Optional[StrictStr] = None
    project_id: Optional[StrictStr] = None
    start_date: Optional[datetime] = None
    status: Optional[StrictStr] = None
    total_cost: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["created_at", "href", "item", "notes", "organization", "organization_id", "period", "project", "project_id", "start_date", "status", "total_cost"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SelfServiceReservationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in item (list)
        _items = []
        if self.item:
            for _item in self.item:
                if _item:
                    _items.append(_item.to_dict())
            _dict['item'] = _items
        # override the default output from pydantic by calling `to_dict()` of period
        if self.period:
            _dict['period'] = self.period.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SelfServiceReservationResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "created_at": obj.get("created_at"),
            "href": obj.get("href"),
            "item": [SelfServiceReservationItemResponse.from_dict(_item) for _item in obj["item"]] if obj.get("item") is not None else None,
            "notes": obj.get("notes"),
            "organization": obj.get("organization"),
            "organization_id": obj.get("organization_id"),
            "period": CreateSelfServiceReservationRequestPeriod.from_dict(obj["period"]) if obj.get("period") is not None else None,
            "project": obj.get("project"),
            "project_id": obj.get("project_id"),
            "start_date": obj.get("start_date"),
            "status": obj.get("status"),
            "total_cost": obj.get("total_cost")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from equinix.services.metalv1.models.project import Project
from typing import Optional, Set
from typing_extensions import Self

class VrfVirtualCircuit(BaseModel):
    """
    VrfVirtualCircuit
    """ # noqa: E501
    created_at: Optional[datetime] = None
    customer_ip: Optional[StrictStr] = Field(default=None, description="An IPv4 address from the subnet that will be used on the Customer side. This parameter is optional, but if supplied, we will use the other usable IP address in the subnet as the Metal IP. By default, the last usable IP address in the subnet will be used.")
    customer_ipv6: Optional[StrictStr] = Field(default=None, description="An IPv6 address from the subnet IPv6 that will be used on the Customer side. This parameter is optional, but if supplied, we will use the other usable IP address in the subnet IPv6 as the Metal IPv6. By default, the last usable IP address in the subnet IPv6 will be used.")
    description: Optional[StrictStr] = None
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    md5: Optional[StrictStr] = Field(default=None, description="The MD5 password for the BGP peering in plaintext (not a checksum).")
    metal_ip: Optional[StrictStr] = Field(default=None, description="An IPv4 address from the subnet that will be used on the Metal side. This parameter is optional, but if supplied, we will use the other usable IP address in the subnet as the Customer IP. By default, the first usable IP address in the subnet will be used.")
    metal_ipv6: Optional[StrictStr] = Field(default=None, description="An IPv6 address from the subnet IPv6 that will be used on the Metal side. This parameter is optional, but if supplied, we will use the other usable IPv6 address in the subnet IPv6 as the Customer IP. By default, the first usable IPv6 address in the subnet IPv6 will be used.")
    name: Optional[StrictStr] = None
    nni_vlan: Optional[StrictInt] = None
    peer_asn: Optional[Annotated[int, Field(le=4294967295, strict=True, ge=0)]] = Field(default=None, description="The peer ASN that will be used with the VRF on the Virtual Circuit.")
    port: Optional[InterconnectionPort] = None
    project: Optional[Project] = None
    speed: Optional[StrictInt] = Field(default=None, description="integer representing bps speed")
    status: Optional[StrictStr] = Field(default=None, description="The status changes of a VRF virtual circuit are generally the same as Virtual Circuits that aren't in a VRF. However, for VRF Virtual Circuits on Fabric VCs, the status will change to 'waiting_on_peering_details' once the Fabric service token associated with the virtual circuit has been redeemed on Fabric, and Metal has found the associated Fabric connection. At this point, users can update the subnet, MD5 password, customer IP and/or metal IP accordingly. For VRF Virtual Circuits on Dedicated Ports, we require all peering details to be set on creation of a VRF Virtual Circuit. The status will change to `changing_peering_details` whenever an active VRF Virtual Circuit has any of its peering details updated.")
    subnet: Optional[StrictStr] = Field(default=None, description="The /30 or /31 IPv4 subnet of one of the VRF IP Blocks that will be used with the VRF for the Virtual Circuit. This subnet does not have to be an existing VRF IP reservation, as we will create the VRF IP reservation on creation if it does not exist. The Metal IP and Customer IP must be IPs from this subnet. For /30 subnets, the network and broadcast IPs cannot be used as the Metal or Customer IP.")
    subnet_ipv6: Optional[StrictStr] = Field(default=None, description="The /126 or /127 IPv6 subnet of one of the VRF IP Blocks that will be used with the VRF for the Virtual Circuit. This subnet does not have to be an existing VRF IP reservation, as we will create the VRF IP reservation on creation if it does not exist. The Metal IPv6 and Customer IPv6 must be IPs from this subnet. For /126 subnets, the network and broadcast IPs cannot be used as the Metal IPv6 or Customer IPv6. The subnet specified must be contained within an already-defined IP Range for the VRF.")
    tags: Optional[List[StrictStr]] = None
    type: Optional[StrictStr] = None
    updated_at: Optional[datetime] = None
    vrf: Vrf
    __properties: ClassVar[List[str]] = ["created_at", "customer_ip", "customer_ipv6", "description", "href", "id", "md5", "metal_ip", "metal_ipv6", "name", "nni_vlan", "peer_asn", "port", "project", "speed", "status", "subnet", "subnet_ipv6", "tags", "type", "updated_at", "vrf"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['pending', 'waiting_on_peering_details', 'activating', 'changing_peering_details', 'deactivating', 'deleting', 'active', 'expired', 'activation_failed', 'changing_peering_details_failed', 'deactivation_failed', 'delete_failed']):
            raise ValueError("must be one of enum values ('pending', 'waiting_on_peering_details', 'activating', 'changing_peering_details', 'deactivating', 'deleting', 'active', 'expired', 'activation_failed', 'changing_peering_details_failed', 'deactivation_failed', 'delete_failed')")
        return value

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['vrf']):
            raise ValueError("must be one of enum values ('vrf')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VrfVirtualCircuit from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of port
        if self.port:
            _dict['port'] = self.port.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        # override the default output from pydantic by calling `to_dict()` of vrf
        if self.vrf:
            _dict['vrf'] = self.vrf.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VrfVirtualCircuit from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "created_at": obj.get("created_at"),
            "customer_ip": obj.get("customer_ip"),
            "customer_ipv6": obj.get("customer_ipv6"),
            "description": obj.get("description"),
            "href": obj.get("href"),
            "id": obj.get("id"),
            "md5": obj.get("md5"),
            "metal_ip": obj.get("metal_ip"),
            "metal_ipv6": obj.get("metal_ipv6"),
            "name": obj.get("name"),
            "nni_vlan": obj.get("nni_vlan"),
            "peer_asn": obj.get("peer_asn"),
            "port": InterconnectionPort.from_dict(obj["port"]) if obj.get("port") is not None else None,
            "project": Project.from_dict(obj["project"]) if obj.get("project") is not None else None,
            "speed": obj.get("speed"),
            "status": obj.get("status"),
            "subnet": obj.get("subnet"),
            "subnet_ipv6": obj.get("subnet_ipv6"),
            "tags": obj.get("tags"),
            "type": obj.get("type"),
            "updated_at": obj.get("updated_at"),
            "vrf": Vrf.from_dict(obj["vrf"]) if obj.get("vrf") is not None else None
        })
        return _obj

from equinix.services.metalv1.models.interconnection_port import InterconnectionPort
from equinix.services.metalv1.models.vrf import Vrf
# TODO: Rewrite to not use raise_errors
VrfVirtualCircuit.model_rebuild(raise_errors=False)

